@@ -315,14 +315,14 @@ sub out_interface ($$$$$$@) {
 	if ($suppress_output) {
 	    # do nothing
 	} elsif ($suppress_curses) {
-	    printf STDOUT ("%2d  %-24s %10s %10s",
+	    printf STDOUT ("%5d  %-24s %10s %10s",
 			   $index,
 			   defined $descr ? $descr : '',
 			   defined $in ? $in : '-',
 			   defined $out ? $out : '-');
 	} else {
 	    $win->addstr ($linecount, 0,
-			  sprintf ("%2d  %-24s %10s %10s",
+			  sprintf ("%5d  %-24s %10s %10s",
 				   $index,
 				   defined $descr ? $descr : '',
 				   defined $in ? $in : '-',
@@ -372,14 +372,14 @@ sub out_interface ($$$$$$@) {
 	if ($suppress_output) {
 	    # do nothing
 	} elsif ($suppress_curses) {
-	    printf STDOUT ("%2d  %-24s %s %s",
+	    printf STDOUT ("%5d  %-24s %s %s",
 			   $index,
 			   defined $descr ? $descr : '',
 			   pretty_ps ($in, $d_in),
 			   pretty_ps ($out, $d_out));
 	} else {
 	    $win->addstr ($linecount, 0,
-			  sprintf ("%2d  %-24s %s %s",
+			  sprintf ("%5d  %-24s %s %s",
 				   $index,
 				   defined $descr ? $descr : '',
 				   pretty_ps ($in, $d_in),
@@ -457,13 +457,13 @@ sub out_switching_engine ($$$$$$@) {
 	if ($suppress_output) {
 	    # do nothing
 	} elsif ($suppress_curses) {
-	    printf STDOUT ("%2d %10s %10s\n",
+	    printf STDOUT ("%5d %10s %10s\n",
 			   $index,
 			   defined $pkts ? $pkts : '-',
 			   defined $octets ? $octets : '-');
 	} else {
 	    $win->addstr ($linecount, 0,
-			  sprintf ("%2d %10s %10s",
+			  sprintf ("%5d %10s %10s",
 				   $index,
 				   defined $pkts ? $pkts : '-',
 				   defined $octets ? $octets : '-'));
@@ -554,8 +554,8 @@ while (1) {
 					 $max_repetitions));
 	    $win->standout();
 	    $win->addstr (1, 0,
-			  sprintf (("%2s  %-24s %10s %10s"),
-				   "ix", "name",
+			  sprintf (("%5s  %-24s %10s %10s"),
+				   "index", "name",
 				   "bits/s", "bits/s"));
 	    if ($show_out_discards) {
 		$win->addstr (sprintf ((" %8s"),
